# Gerador de Senhas

Descrição. 
O programa Gerador de Senhas, é usado para:
	- Gerar senhas aleatórias
	- Contendo letras maiúsculas, minúsculas, números e simbolos
	- A senha pode ser do tamanho que o usuário escolher

## Instalação

Use o instalador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalar o ger_senhas

```bash
pip install ger_senhas
```

## Como usar

```python
from ger_senhas import gerador_de_senhas
gerador_de_senhas.gs()
```

## Autor
Fellipe Marlus

## License
[MIT](https://choosealicense.com/licenses/mit/)